chitose.app.bsky.embed package
==============================

Submodules
----------

chitose.app.bsky.embed.external module
--------------------------------------

.. automodule:: chitose.app.bsky.embed.external
   :members:
   :undoc-members:
   :show-inheritance:

chitose.app.bsky.embed.images module
------------------------------------

.. automodule:: chitose.app.bsky.embed.images
   :members:
   :undoc-members:
   :show-inheritance:

chitose.app.bsky.embed.record module
------------------------------------

.. automodule:: chitose.app.bsky.embed.record
   :members:
   :undoc-members:
   :show-inheritance:

chitose.app.bsky.embed.record\_with\_media module
-------------------------------------------------

.. automodule:: chitose.app.bsky.embed.record_with_media
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: chitose.app.bsky.embed
   :members:
   :undoc-members:
   :show-inheritance:
